@@ -25,6 +25,7 @@ funcincludes() {
 
 includes=''
 checkfunc d__fwalk '_fwalk'
+checkfunc d_accept4 'accept4' "0,NULL,NULL,0" 'sys/socket.h sys/types.h'
 checkfunc d_access 'access' "NULL,0" 'unistd.h'
 checkfunc d_accessx 'accessx'
 checkfunc d_aintl 'aintl'
@@ -53,7 +54,8 @@ checkfunc d_dladdr 'dladdr' 'NULL, NULL' 'dlfcn.h'
 checkfunc d_dlerror 'dlerror'
 checkfunc d_dlopen 'dlopen'
 checkfunc d_drand48 'drand48'
-checkfunc d_dup2 'dup2' "0,0"
+checkfunc d_dup2 'dup2' "0,0" 'unistd.h'
+checkfunc d_dup3 'dup3' "0,0,0" 'fcntl.h unistd.h'
 checkfunc d_duplocale 'duplocale' '0' 'locale.h'
 checkfunc d_eaccess 'eaccess'
 checkfunc d_endgrent 'endgrent'
@@ -137,24 +139,29 @@ checkfunc d_lchown 'lchown' "NULL, 0, 0" 'unistd.h'
 checkfunc d_link 'link' 'NULL,NULL'
 checkfunc d_linkat 'linkat' '0,NULL,0,NULL,0'
 checkfunc d_localtime64 'localtime64'
+checkfunc d_localeconv_l 'localeconv_l' 'NULL' 'locale.h'
 checkfunc d_locconv 'localeconv'
 checkfunc d_lockf 'lockf'
 checkfunc d_lstat 'lstat'
 checkfunc d_madvise 'madvise'
 checkfunc d_malloc_good_size 'malloc_good_size'
 checkfunc d_malloc_size 'malloc_size'
-checkfunc d_mblen 'mblen'
+checkfunc d_mblen 'mblen' '"", 0' 'stdlib.h'
 checkfunc d_mbstowcs 'mbstowcs'
-checkfunc d_mbtowc 'mbtowc'
+checkfunc d_mbtowc 'mbtowc' 'NULL, NULL, 0' 'stdlib.h'
+checkfunc d_mbrlen 'mbrlen' 'NULL, 0, NULL' 'wchar.h'
+checkfunc d_mbrtowc 'mbrtowc' 'NULL, NULL, 0, NULL' 'wchar.h'
 checkfunc d_memchr 'memchr' "NULL, 0, 0" 'string.h'
 checkfunc d_memcmp 'memcmp' "NULL, NULL, 0" 'string.h'
 checkfunc d_memcpy 'memcpy' "NULL, NULL, 0" 'string.h'
 checkfunc d_memmem 'memmem' "NULL, 0, NULL, 0" 'string.h'
 checkfunc d_memmove 'memmove' "NULL, NULL, 0" 'string.h'
+checkfunc d_memrchr 'memrchr' "NULL, 0, 0" 'string.h'
 checkfunc d_memset 'memset' "NULL, 0, 0" 'string.h'
 checkfunc d_mkdir 'mkdir' 'NULL, 0'
 checkfunc d_mkdtemp 'mkdtemp'
 checkfunc d_mkfifo 'mkfifo'
+checkfunc d_mkostemp 'mkostemp' 'NULL,0' 'stdlib.h'
 checkfunc d_mkstemp 'mkstemp' 'NULL'
 checkfunc d_mkstemps 'mkstemps'
 checkfunc d_mktime 'mktime' 'NULL'
@@ -170,11 +177,13 @@ checkfunc d_munmap 'munmap'
 checkfunc d_newlocale 'newlocale' '0,NULL,0' 'locale.h'
 checkfunc d_nice 'nice' '0'
 checkfunc d_nl_langinfo 'nl_langinfo'
+checkfunc d_nl_langinfo_l 'nl_langinfo_l'
 checkfunc d_open 'open' "NULL,0,0" 'sys/types.h sys/stat.h fcntl.h'
 checkfunc d_openat 'openat' "0,NULL,0,0" 'sys/types.h sys/stat.h fcntl.h'
 checkfunc d_pathconf 'pathconf'
 checkfunc d_pause 'pause'
-checkfunc d_pipe 'pipe' 'NULL'
+checkfunc d_pipe 'pipe' 'NULL' 'fcntl.h unistd.h'
+checkfunc d_pipe2 'pipe' 'NULL,0' 'fcntl.h unistd.h'
 checkfunc d_poll 'poll'
 checkfunc d_prctl 'prctl'
 checkfunc d_pthread_atfork 'pthread_atfork'
@@ -250,9 +259,11 @@ checkfunc d_strerror_l 'strerror_l'
 checkfunc d_strftime 'strftime' "NULL,0,NULL,NULL" 'time.h'
 checkfunc d_strlcat 'strlcat'
 checkfunc d_strlcpy 'strlcpy'
+checkfunc d_strnlen 'strnlen' '"",0' 'string.h'
 checkfunc d_strtod 'strtod' 'NULL,NULL'
 checkfunc d_strtol 'strtol' 'NULL,NULL,0'
 checkfunc d_strtold 'strtold'
+checkfunc d_strtold_l 'strtold_l'
 checkfunc d_strtoll 'strtoll'
 checkfunc d_strtoq 'strtoq'
 checkfunc d_strtoul 'strtoul' 'NULL,NULL,0'
